@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -104,8 +104,6 @@ __all__ = (
     'Dimension',
     'Dimensions',
     'Direction',
-    'Enumeration',
-    'enumeration',
     'FlowMode',
     'FontStyle',
     'HAlign',
@@ -126,6 +124,7 @@ __all__ = (
     'Location',
     'MapType',
     'MarkerType',
+    'Movable',
     'NamedColor',
     'NumeralLanguage',
     'Orientation',
@@ -133,8 +132,11 @@ __all__ = (
     'PaddingUnits',
     'Palette',
     'Place',
+    'RegionSelectionMode',
     'RenderLevel',
     'ResetPolicy',
+    'Resizable',
+    'ResolutionType',
     'RoundingFunction',
     'ScrollbarPolicy',
     'SelectionMode',
@@ -417,6 +419,9 @@ MarkerType = enumeration(
     "triangle", "triangle_dot", "triangle_pin", "x", "y",
 )
 
+#: Indicates in which dimensions an object (a renderer or an UI element) can be moved.
+Movable = enumeration("none", "x", "y", "both")
+
 #: Specify one of the CSS4 named colors (https://www.w3.org/TR/css-color-4/#named-colors)
 NamedColor = enumeration(*colors.named.__all__, case_sensitive=False)
 
@@ -430,7 +435,8 @@ NumeralLanguage = enumeration("be-nl", "chs", "cs", "da-dk", "de-ch", "de", "en"
 Orientation = enumeration("horizontal", "vertical")
 
 #: Specify an output backend to render a plot area onto
-OutputBackend = enumeration("canvas", "svg", "webgl")
+OutputBackendType = Literal["canvas", "svg", "webgl"]
+OutputBackend = enumeration(OutputBackendType)
 
 #: Whether range padding should be interpreted a percentage or and absolute quantity
 PaddingUnits = enumeration("percent", "absolute")
@@ -448,14 +454,25 @@ RenderLevel = enumeration("image", "underlay", "glyph", "guide", "annotation", "
 #: What reset actions should occur on a Plot reset
 ResetPolicy = enumeration("standard", "event_only")
 
+#: Indicates in which dimensions an object (a renderer or an UI element) can be resized.
+Resizable = enumeration("none", "left", "right", "top", "bottom", "x", "y", "all")
+
+#: Specify which resolutions should be used for stripping of leading zeros
+ResolutionType = enumeration("microseconds", "milliseconds", "seconds", "minsec", "minutes", "hourmin", "hours", "days", "months", "years")
+
 #: Specify a policy for  how numbers should be rounded
 RoundingFunction = enumeration("round", "nearest", "floor", "rounddown", "ceil", "roundup")
 
 #: Scrollbar policies
 ScrollbarPolicy = enumeration("auto", "visible", "hidden")
 
+#: Region selection modes
+RegionSelectionModeType = Literal["replace", "append", "intersect", "subtract", "xor"]
+RegionSelectionMode = enumeration(RegionSelectionModeType)
+
 #: Selection modes
-SelectionMode = enumeration("replace", "append", "intersect", "subtract")
+SelectionModeType = Literal[RegionSelectionModeType, "toggle"]
+SelectionMode = enumeration(SelectionModeType)
 
 #: Sizing mode policies
 SizingModeType = Literal["stretch_width", "stretch_height", "stretch_both", "scale_width", "scale_height", "scale_both", "fixed", "inherit"]
@@ -488,20 +505,41 @@ TextureRepetition = enumeration("repeat", "repeat_x", "repeat_y", "no_repeat")
 #: Well known tool icon names
 ToolIcon = enumeration(
   "append_mode",
+  "arrow_down_to_bar",
+  "arrow_up_from_bar",
+  "auto_box_zoom",
+  "bold",
   "box_edit",
   "box_select",
   "box_zoom",
+  "caret_down",
+  "caret_left",
+  "caret_right",
+  "caret_up",
+  "check",
+  "chevron_down",
+  "chevron_left",
+  "chevron_right",
+  "chevron_up",
   "clear_selection",
   "copy",
   "crosshair",
+  "delete",
   "freehand_draw",
+  "fullscreen",
   "help",
   "hover",
   "intersect_mode",
+  "invert_selection",
+  "italic",
   "lasso_select",
   "line_edit",
+  "maximize",
+  "minimize",
   "pan",
+  "pin",
   "point_draw",
+  "pointer",
   "poly_draw",
   "poly_edit",
   "polygon_select",
@@ -510,13 +548,30 @@ ToolIcon = enumeration(
   "replace_mode",
   "reset",
   "save",
+  "see_off",
+  "see_on",
+  "settings",
+  "square",
+  "square_check",
   "subtract_mode",
   "tap_select",
+  "text_align_center",
+  "text_align_left",
+  "text_align_right",
   "undo",
+  "unknown",
+  "unpin",
   "wheel_pan",
   "wheel_zoom",
-  "xpan",
-  "ypan",
+  "x_box_select",
+  "x_box_zoom",
+  "x_grip",
+  "x_pan",
+  "xor_mode",
+  "y_box_select",
+  "y_box_zoom",
+  "y_grip",
+  "y_pan",
   "zoom_in",
   "zoom_out",
 )
