@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -42,6 +42,7 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import difflib
 import typing as tp
+from math import nan
 from typing import Literal
 
 # Bokeh imports
@@ -50,6 +51,7 @@ from ..core.enums import (
     Dimension,
     Dimensions,
     KeyModifier,
+    RegionSelectionMode,
     SelectionMode,
     ToolIcon,
     TooltipAttachment,
@@ -58,6 +60,7 @@ from ..core.enums import (
 from ..core.has_props import abstract
 from ..core.properties import (
     Alpha,
+    Any,
     AnyRef,
     Auto,
     Bool,
@@ -93,12 +96,6 @@ from ..model import Model
 from ..util.strings import nice_join
 from .annotations import BoxAnnotation, PolyAnnotation, Span
 from .callbacks import Callback
-from .coordinates import (
-    FrameBottom,
-    FrameLeft,
-    FrameRight,
-    FrameTop,
-)
 from .dom import Template
 from .glyphs import (
     HStrip,
@@ -111,7 +108,8 @@ from .glyphs import (
     VStrip,
     XYGlyph,
 )
-from .ranges import Range1d
+from .nodes import Node
+from .ranges import Range
 from .renderers import DataRenderer, GlyphRenderer
 from .ui import UIElement
 
@@ -195,6 +193,10 @@ class Tool(Model):
     user interface as a tooltip.
     """)
 
+    visible = Bool(default=True, help="""
+    Whether a tool button associated with this tool should appear in the toolbar.
+    """)
+
     _known_aliases: tp.ClassVar[dict[str, tp.Callable[[], Tool]]] = {}
 
     @classmethod
@@ -299,12 +301,6 @@ class SelectTool(GestureTool):
     all renderers on a plot.
     """)
 
-    mode = Enum(SelectionMode, default="replace", help="""
-    Defines what should happen when a new selection is made. The default
-    is to replace the existing selection. Other options are to append to
-    the selection, intersect with it or subtract from it.
-    """)
-
 @abstract
 class RegionSelectTool(SelectTool):
     ''' Base class for region selection tools (e.g. box, polygon, lasso).
@@ -315,6 +311,18 @@ class RegionSelectTool(SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    mode = Enum(RegionSelectionMode, default="replace", help="""
+    Defines what should happen when a new selection is made. The default
+    is to replace the existing selection. Other options are to append to
+    the selection, intersect with it or subtract from it.
+
+    Defines what should happen when a new selection is made.
+
+    The default is to replace the existing selection. Other options are to
+    append to the selection, intersect with it, subtract from it or compute
+    a symmetric difference with it.
+    """)
+
     continuous = Bool(False, help="""
     Whether a selection computation should happen continuously during selection
     gestures, or only once when the selection region is completed.
@@ -344,11 +352,7 @@ class InspectTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    toggleable = Bool(True, help="""
-    Whether an on/off toggle button should appear in the toolbar for this
-    inspection tool. If ``False``, the viewers of a plot will not be able to
-    toggle the inspector on or off using the toolbar.
-    """)
+    toggleable = DeprecatedAlias("visible", since=(3, 4, 0))
 
 class Toolbar(UIElement):
     ''' Collect tools to display for a single plot.
@@ -436,10 +440,14 @@ DEFAULT_RANGE_OVERLAY = lambda: BoxAnnotation(
     visible=True,
     editable=True,
     propagate_hover=True,
-    left_limit=FrameLeft(),
-    right_limit=FrameRight(),
-    top_limit=FrameTop(),
-    bottom_limit=FrameBottom(),
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
+    left_limit=Node.frame.left,
+    right_limit=Node.frame.right,
+    top_limit=Node.frame.top,
+    bottom_limit=Node.frame.bottom,
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
@@ -470,12 +478,12 @@ class RangeTool(Tool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    x_range = Nullable(Instance(Range1d), help="""
+    x_range = Nullable(Instance(Range), help="""
     A range synchronized to the x-dimension of the overlay. If None, the overlay
     will span the entire x-dimension.
     """)
 
-    y_range = Nullable(Instance(Range1d), help="""
+    y_range = Nullable(Instance(Range), help="""
     A range synchronized to the y-dimension of the overlay. If None, the overlay
     will span the entire y-dimension.
     """)
@@ -714,6 +722,14 @@ class TapTool(Tap, SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    mode = Enum(SelectionMode, default="toggle", help="""
+    Defines what should happen when a new selection is made.
+
+    The default is to toggle the existing selection. Other options are to
+    replace the selection, append to it, intersect with it, subtract from
+    it or compute a symmetric difference with it.
+    """)
+
     behavior = Enum("select", "inspect", default="select", help="""
     This tool can be configured to either make selections or inspections
     on associated data sources. The difference is that selection changes
@@ -733,7 +749,7 @@ class TapTool(Tap, SelectTool):
 
     .. warning::
         Configuring modifiers is a platform dependent feature and
-        can make this tool unsable for example on mobile devices.
+        can make this tool unusable for example on mobile devices.
 
     """).accepts(Enum(KeyModifier), lambda key_mod: {key_mod: True})
 
@@ -834,6 +850,10 @@ DEFAULT_BOX_ZOOM_OVERLAY = InstanceDefault(BoxAnnotation,
     level="overlay",
     visible=False,
     editable=False,
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
     top_units="canvas",
     left_units="canvas",
     bottom_units="canvas",
@@ -851,6 +871,10 @@ DEFAULT_BOX_SELECT_OVERLAY = InstanceDefault(BoxAnnotation,
     level="overlay",
     visible=False,
     editable=True,
+    left=nan,
+    right=nan,
+    top=nan,
+    bottom=nan,
     top_units="data",
     left_units="data",
     bottom_units="data",
@@ -1076,7 +1100,7 @@ class PolySelectTool(Tap, RegionSelectTool):
     The polygon selection tool allows users to make selections on a
     Plot by indicating a polygonal region with mouse clicks. single
     clicks (or taps) add successive points to the definition of the
-    polygon, and a double click (or tap) indicates the selection
+    polygon, and a press click (or tap) indicates the selection
     region is ready.
 
     See :ref:`ug_styling_plots_selected_unselected_glyphs` for information
@@ -1188,13 +1212,13 @@ class CustomJSHover(Model):
     The snippet will be made into the body of a function and therefore requires
     a return statement.
 
-    Example:
+    **Example**
 
-        .. code-block:: javascript
+    .. code-block:: javascript
 
-            code = '''
-            return value + " total"
-            '''
+        code = '''
+        return value + " total"
+        '''
     """)
 
 class HoverTool(InspectTool):
@@ -1241,19 +1265,19 @@ class HoverTool(InspectTool):
 
     Hover tool does not currently work with the following glyphs:
 
-        .. hlist::
-            :columns: 3
+    .. hlist::
+        :columns: 3
 
-            * annulus
-            * arc
-            * bezier
-            * image_url
-            * oval
-            * patch
-            * quadratic
-            * ray
-            * step
-            * text
+        * annulus
+        * arc
+        * bezier
+        * image_url
+        * oval
+        * patch
+        * quadratic
+        * ray
+        * step
+        * text
 
     .. |hover_icon| image:: /_images/icons/Hover.png
         :height: 24px
@@ -1507,12 +1531,27 @@ class EditTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    default_overrides = Dict(String, Any, default={}, help="""
+    Padding values overriding ``ColumnarDataSource.default_values``.
+
+    Defines values to insert into non-coordinate columns when a new glyph is
+    inserted into the ``ColumnDataSource`` columns, e.g. when a circle glyph
+    defines ``"x"``, ``"y"`` and ``"color"`` columns, adding a new point will
+    add the x and y-coordinates to ``"x"`` and ``"y"`` columns and the color
+    column will be filled with the defined default value.
+    """)
+
     empty_value = Either(Bool, Int, Float, Date, Datetime, Color, String, default=0, help="""
-    Defines the value to insert on non-coordinate columns when a new
-    glyph is inserted into the ``ColumnDataSource`` columns, e.g. when a
-    circle glyph defines 'x', 'y' and 'color' columns, adding a new
-    point will add the x and y-coordinates to 'x' and 'y' columns and
-    the color column will be filled with the defined empty value.
+    The "last resort" padding value.
+
+    This is used the same as ``default_values``, when the tool was unable
+    to figure out a default value otherwise. The tool will try the following
+    alternatives in order:
+
+    1. ``EditTool.default_overrides``
+    2. ``ColumnarDataSource.default_values``
+    3. ``ColumnarDataSource``'s inferred default values
+    4. ``EditTool.empty_value``
     """)
 
     # TODO abstract renderers = List(Instance(GlyphRenderer & ...))
@@ -1546,9 +1585,8 @@ class BoxEditTool(EditTool, Drag, Tap):
 
     The supported actions include:
 
-    * Add box: Hold shift then click and drag anywhere on the plot or double
-      tap once to start drawing, move the mouse and double tap again to finish
-      drawing.
+    * Add box: Hold shift then click and drag anywhere on the plot or press
+      once to start drawing, move the mouse and press again to finish drawing.
 
     * Move box: Click and drag an existing box, the box will be dropped once
       you let go of the mouse button.
@@ -1672,8 +1710,8 @@ class PolyDrawTool(PolyTool, Drag, Tap):
 
     The supported actions include:
 
-    * Add patch or multi-line: Double tap to add the first vertex, then use tap
-      to add each subsequent vertex, to finalize the draw action double tap to
+    * Add patch or multi-line: press to add the first vertex, then use tap
+      to add each subsequent vertex, to finalize the draw action press to
       insert the final vertex or press the ESC key.
 
     * Move patch or multi-line: Tap and drag an existing patch/multi-line, the
@@ -1761,11 +1799,11 @@ class PolyEditTool(PolyTool, Drag, Tap):
 
     The supported actions include:
 
-    * Show vertices: Double tap an existing patch or multi-line
+    * Show vertices: press an existing patch or multi-line
 
-    * Add vertex: Double tap an existing vertex to select it, the tool will
+    * Add vertex: press an existing vertex to select it, the tool will
       draw the next point, to add it tap in a new location. To finish editing
-      and add a point double tap otherwise press the ESC key to cancel.
+      and add a point press otherwise press the ESC key to cancel.
 
     * Move vertex: Drag an existing vertex and let go of the mouse button to
       release it.
@@ -1802,7 +1840,7 @@ class LineEditTool(EditTool, Drag, Tap):
 
     The supported actions include:
 
-    * Show intersections: Double tap an existing line
+    * Show intersections: press an existing line
 
     * Move point: Drag an existing point and let go of the mouse button to
       release it.
